# -*- coding: utf-8 -*-
"""
Example for visualizing dBZe sensitivity to cutoff size of the snowflake size distribution.

@author: mgergely
"""

import numpy as np
import matplotlib.pyplot as plt


#######################################
#%% Input


# Input directory
indir = './sensitivity_results/'

# Input file containing dBZe sensitivities [dB/mm], 234 rows x 48 columns
#Filename indicates snowflake representation SSRGA_W04, L15_rimed, L15_unrimed, soft spheroids, or G17_Barrow; X, Ku, Ka, or W radar band; and snowflake size distribution shape parameter mu=0 (mu0), mu=-2 (mu-2), or mu=3 (mu3)
filename = 'SSRGA_W04_Ku_mu0_sensitivities.txt'  # data used for Fig. 4a
#filename = 'L15_rimed_Ku_mu3_sensitivities.txt'  # data used for Fig. 5d
        
# Load dBZe sensitivity data
dBZe_sens = np.loadtxt(indir + filename)


#######################################
#%% Visualization


### Pre-stuff

# Limit dBZe sensitivities for plotting
lim_sens = 0.05
dBZe_sens[dBZe_sens < lim_sens] = lim_sens

# Set maximum dBZe sensitivity for plotting
max_sens = 50.0 

# Data range of sensitivity data
#SSD cutoff size [mm]
Dmax_min = 0.1
Dmax_max = 23.5
#SSD slope parameter [1/mm]
Lambda_min = 0.3
Lambda_max = 5.0


### Figure

fig = plt.figure(figsize=(6,6))
figname = 'dBZe_sensitivity_overview.png'

ax1 = fig.add_subplot(1,1,1)
im_1 = ax1.imshow(np.log10(dBZe_sens).T, interpolation='bilinear', origin='lower', aspect='auto', extent=(Dmax_min,Dmax_max,Lambda_min-0.05,Lambda_max+0.05), cmap=plt.get_cmap('nipy_spectral_r'), vmin=np.log10(lim_sens), vmax=np.log10(max_sens))
cbticks = np.log10(np.array([lim_sens, 0.1, 0.2, 0.5, 1, 2, 5, 10, 20, 50]))
cb1 = fig.colorbar(im_1, orientation='horizontal', pad=0.17, ticks=cbticks)
cb1.set_ticklabels([r'$\leq$0.05', '0.1', '0.2', '0.5', '1', '2', '5', '10', '20', '$\geq$50'])
cb1.set_label(r'Sensitivity $\Delta$dB$Z_{e} / \Delta D_{\mathrm{max}}$ [dB mm$^{-1}$], logarithmic scale', fontsize=12)
ax1.grid()
#ax1.set_xlim([0.1, 23.5])
xlabels = np.array([0.1, 2, 5, 10, 15, 20])
xlabelnames = ['0.1', '2', '5', '10', '15', '20']
ylabels = np.array([0.5, 1.5, 2.5, 3.5, 4.5])
ax1.set_xticks(xlabels)
ax1.set_yticks(ylabels)
ax1.set_xticklabels(xlabelnames)
ax1.set_xlabel(r'SSD cutoff size $D_{\mathrm{max}}$ [mm]', fontsize=12)
ax1.set_ylabel(r'SSD slope $\Lambda$ [mm$^{-1}$]', fontsize=12)
plt.tick_params(axis='both', labelsize=11)

#fig.savefig(figname)  # uncomment to save figure
plt.show()
